// Copyright 2021 The Gitea Authors. All rights reserved.
// Use of this source code is governed by a MIT-style
// license that can be found in the LICENSE file.

package umap

import (
	"code.gitea.io/gitea/models/db"
	user_model "code.gitea.io/gitea/models/user"
	"code.gitea.io/gitea/modules/base"
	"code.gitea.io/gitea/modules/context"
	"code.gitea.io/gitea/modules/setting"
	"code.gitea.io/gitea/modules/structs"
)

const (
	// tpluMapOrganizations umap organizations page template
	tpluMapOrganizations base.TplName = "map/umap"
)

// Organizations render explore organizations page
func Organizations(ctx *context.Context) {
	ctx.Data["UsersIsDisabled"] = setting.Service.Explore.DisableUsersPage
	ctx.Data["Title"] = ctx.Tr("map")
	ctx.Data["PageIsMap"] = true
	ctx.Data["PageIsMapOrganizations"] = true
	ctx.Data["IsRepoIndexerEnabled"] = setting.Indexer.RepoIndexerEnabled

	visibleTypes := []structs.VisibleType{structs.VisibleTypePublic}
	if ctx.User != nil {
		visibleTypes = append(visibleTypes, structs.VisibleTypeLimited, structs.VisibleTypePrivate)
	}

	RenderUserSearch(ctx, &user_model.SearchUserOptions{
		Actor:       ctx.User,
		Type:        user_model.UserTypeOrganization,
		ListOptions: db.ListOptions{PageSize: 8 * 1024}, // Get all users
		Visible:     visibleTypes,
	}, tpluMapOrganizations)
}
